Enum TakerOrder
pub enum TakerOrder {
Order(Order),
LiquidationOrder(StreamLiquidationOrder),
}Expand description
The taker order that was matched on the orderbook. Can be a regular order or a liquidation order.
Variants
Order(Order)
LiquidationOrder(StreamLiquidationOrder)
Implementations
impl TakerOrder
impl TakerOrder
pub fn encode(&self, buf: &mut impl BufMut)
pub fn encode(&self, buf: &mut impl BufMut)
Encodes the message to a buffer.
pub fn merge(
field: &mut Option<TakerOrder>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<TakerOrder>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
pub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.